@@ -2,9 +2,10 @@ from rest_framework.relations import PrimaryKeyRelatedField
 from rest_framework.utils import model_meta
 from rest_framework import serializers
 from django.db.models import ForeignKey
-from copy import deepcopy
 
-from air_drf_relation.fields import RelatedField
+from air_drf_relation.context_builder import set_empty_request_in_kwargs
+from air_drf_relation.extra_kwargs import ExtraKwargsFactory
+from air_drf_relation.fields import AirRelatedField
 from air_drf_relation.nested_fields_factory import NestedSaveFactory
 
 
@@ -21,11 +22,13 @@ class AirModelSerializer(serializers.ModelSerializer):
         self.user = kwargs.pop('user', None)
         self.nested_save_fields = self._get_nested_save_fields()
         self.nested_save_factory: NestedSaveFactory = None
+        if 'context' not in kwargs:
+            set_empty_request_in_kwargs(kwargs=kwargs)
         if not self.action:
             self._set_action_from_view(kwargs=kwargs)
         if not self.user:
             self._set_user_from_request(kwargs)
-        self.extra_kwargs = self._get_extra_kwargs(extra_kwargs=kwargs.pop('extra_kwargs', {}))
+        self.extra_kwargs = self._get_extra_kwargs(kwargs)
         self._update_extra_kwargs_in_fields()
         super(AirModelSerializer, self).__init__(*args, **kwargs)
         self._set_nested_save_factory()
@@ -58,7 +61,7 @@ class AirModelSerializer(serializers.ModelSerializer):
         for el in hidden_fields:
             del self.fields[el]
         for field_name, field in self.fields.items():
-            if not isinstance(field, RelatedField):
+            if not isinstance(field, AirRelatedField):
                 continue
             model_field: ForeignKey = info.relations[field_name].model_field
             field_kwargs = field._kwargs
@@ -77,7 +80,7 @@ class AirModelSerializer(serializers.ModelSerializer):
             if not self.initial_data.get(field_name):
                 continue
             function_name = None
-            if isinstance(field, RelatedField):
+            if isinstance(field, AirRelatedField):
                 if field.queryset_function_disabled:
                     return
                 function_name = field.queryset_function_name
@@ -89,33 +92,15 @@ class AirModelSerializer(serializers.ModelSerializer):
     def _get_related_fields(self):
         related_fields = dict()
         for field_name, field in self.fields.items():
-            if type(field) in (RelatedField, PrimaryKeyRelatedField):
+            if type(field) in (AirRelatedField, PrimaryKeyRelatedField):
                 related_fields[field_name] = field
         return related_fields
 
-    def _get_extra_kwargs(self, extra_kwargs: dict):
-        meta_extra_kwargs = deepcopy(self.Meta.extra_kwargs) if hasattr(self.Meta, 'extra_kwargs') else {}
+    def _get_extra_kwargs(self, kwargs: dict):
+        data = {'extra_kwargs': kwargs.pop('extra_kwargs', {})}
+        extra_kwargs = ExtraKwargsFactory(meta=self.Meta, data=data, action=self.action).init().extra_kwargs
         self._delete_custom_extra_kwargs_in_meta()
-        action_extra_kwargs = {}
-        if hasattr(self.Meta, 'action_extra_kwargs') and self.action:
-            _action_extra_kwargs = deepcopy(self.Meta.action_extra_kwargs)
-            _current_actions = {}
-            for key, value in _action_extra_kwargs.items():
-                keys = key.replace(' ', '').split(',')
-                for current_key in keys:
-                    _current_actions[current_key] = value
-            action_extra_kwargs = _current_actions.get(self.action)
-            if not action_extra_kwargs:
-                action_extra_kwargs = _current_actions.get('_', {})
-
-        unique_field_names = list(extra_kwargs.keys()) + list(meta_extra_kwargs.keys()) + list(
-            action_extra_kwargs.keys())
-        unique_field_names = list(set(unique_field_names))
-        result_kwargs = {}
-        for name in unique_field_names:
-            result_kwargs[name] = {**meta_extra_kwargs.get(name, {}), **action_extra_kwargs.get(name, {}),
-                                   **extra_kwargs.get(name, {})}
-        return result_kwargs
+        return extra_kwargs
 
     def _update_extra_kwargs_in_fields(self):
         for key, value in self.extra_kwargs.items():
@@ -171,3 +156,10 @@ class AirModelSerializer(serializers.ModelSerializer):
         self.nested_save_factory.created = False
         self.nested_save_factory.save_nested_fields()
         return instance
+
+    def __new__(cls, *args, **kwargs):
+        if kwargs.pop('many', False):
+            if 'context' not in kwargs:
+                set_empty_request_in_kwargs(kwargs=kwargs)
+            return cls.many_init(*args, **kwargs)
+        return super().__new__(cls, *args, **kwargs)
