@@ -1,3 +1,5 @@
+from uuid import uuid4
+
 from django.db import models
 
 
@@ -14,3 +16,9 @@ class Cabinet(models.Model):
 class School(models.Model):
     name = models.CharField(max_length=256)
     children = models.ManyToManyField(Child, related_name='schools')
+
+
+class Parent(models.Model):
+    id = None
+    uuid = models.UUIDField(default=uuid4, editable=True, primary_key=True, unique=True)
+    name = models.CharField(max_length=128, unique=True)
